@@ -1,4 +1,6 @@
-# Copyright (C) 2007-2015 X2Go Project - http://wiki.x2go.org
+# Copyright (C) 2007-2023 X2Go Project - https://wiki.x2go.org
+# Copyright (C) 2007-2023 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>
+# Copyright (C) 2007-2023 Heinz-Markus Graesing <heinz-m.graesing@obviously-nice.de>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,9 +16,6 @@
 # along with this program; if not, write to the
 # Free Software Foundation, Inc.,
 # 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-#
-# Copyright (C) 2007-2015 Oleksandr Shneyder <oleksandr.shneyder@obviously-nice.de>
-# Copyright (C) 2007-2015 Heinz-Markus Graesing <heinz-m.graesing@obviously-nice.de>
 
 package X2Go::Server::DB::PostgreSQL;
 
@@ -34,6 +33,7 @@ use strict;
 use DBI;
 use POSIX;
 use Sys::Syslog qw( :standard :macros );
+use File::Copy;
 
 use X2Go::Log qw( loglevel );
 use X2Go::Config qw( get_config get_sqlconfig );
@@ -86,16 +86,45 @@ sub init_db
 			$port='5432';
 		}
 		my $passfile;
+		my $old_location;
 		if ($uname eq 'root')
 		{
 			$dbuser='x2godbuser';
-			$passfile="/etc/x2go/x2gosql/passwords/x2goadmin";
+			$old_location = "/etc/x2go/x2gosql/passwords/x2goadmin";
+			$passfile="/etc/x2go/x2gosql/passwords/x2gopgadmin";
 		}
 		else
 		{
 			$dbuser="x2gouser_$uname";
-			$passfile="$homedir/.x2go/sqlpass";
+			$old_location = "$homedir/.x2go/sqlpass";
+			$passfile="$homedir/.x2go/pgsqlpass";
 		}
+
+		my $move_file = 0;
+
+		if ((-e $old_location) && (-e $passfile))
+		{
+			if (-z $passfile)
+			{
+				$move_file = 1;
+			}
+			else
+			{
+				die "Detected existing files in both the legacy location '$old_location' and new location '$passfile'. New location file is non-empty, aborting.<br>";
+			}
+		}
+
+		if ((-e $old_location) && (! -e $passfile))
+		{
+			$move_file = 1;
+		}
+
+		if ($move_file)
+		{
+			# Password file needs move.
+			move($old_location, $passfile) or die "Unable to move PostgreSQL user password file from '$old_location' to '$passfile'<br>";
+		}
+
 		$sslmode=$SqlConfig->param("postgres.ssl");
 		if (!$sslmode)
 		{
@@ -112,7 +141,7 @@ sub dbsys_rmsessionsroot
 {
 	init_db();
 	my $sid=shift or die "argument \"session_id\" missed";
-	my $dbh=DBI->connect("dbi:Pg:dbname=$db;host=$host;port=$port;sslmode=$sslmode", 
+	my $dbh=DBI->connect("dbi:Pg:dbname=$db;host=$host;port=$port;sslmode=$sslmode",
 	                     "$dbuser", "$dbpass",{AutoCommit => 1}) or die $_;
 	my $sth=$dbh->prepare("delete from sessions  where session_id='$sid'");
 	$sth->execute() or die;
@@ -140,7 +169,7 @@ sub dbsys_listsessionsroot
 	init_db();
 	my $server=shift or die "argument \"server\" missed";
 	my @strings;
-	my $dbh=DBI->connect("dbi:Pg:dbname=$db;host=$host;port=$port;sslmode=$sslmode", 
+	my $dbh=DBI->connect("dbi:Pg:dbname=$db;host=$host;port=$port;sslmode=$sslmode",
 	                     "$dbuser", "$dbpass",{AutoCommit => 1}) or die $_;
 	my $sth;
 	if ($with_TeKi) {
@@ -159,7 +188,7 @@ sub dbsys_listsessionsroot
 	$sth->execute()or die;
 	my @data;
 	my $i=0;
-	while (@data = $sth->fetchrow_array) 
+	while (@data = $sth->fetchrow_array)
 	{
 		@strings[$i++]=join('|',@data);
 	}
@@ -190,7 +219,7 @@ sub dbsys_listsessionsroot_all
 	$sth->execute()or die;
 	my @data;
 	my $i=0;
-	while (@data = $sth->fetchrow_array) 
+	while (@data = $sth->fetchrow_array)
 	{
 		@strings[$i++]=join('|',@data);
 	}
@@ -210,7 +239,7 @@ sub dbsys_getmounts
 	$sth->execute()or die;
 	my @data;
 	my $i=0;
-	while (@data = $sth->fetchrow_array) 
+	while (@data = $sth->fetchrow_array)
 	{
 		@mounts[$i++]=join("|",@data);
 	}
@@ -230,7 +259,7 @@ sub db_getmounts
 	$sth->execute()or die;
 	my @data;
 	my $i=0;
-	while (@data = $sth->fetchrow_array) 
+	while (@data = $sth->fetchrow_array)
 	{
 		@mounts[$i++]=join("|",@data);
 	}
@@ -431,7 +460,7 @@ sub db_getstatus
 	my $sth=$dbh->prepare("select status from sessions_view where session_id = '$sid'");
 	$sth->execute($sid) or die;
 	my @data;
-	if (@data = $sth->fetchrow_array) 
+	if (@data = $sth->fetchrow_array)
 	{
 		$status=@data[0];
 	}
@@ -451,7 +480,7 @@ sub db_getdisplays
 	$sth->execute()or die;
 	my @data;
 	my $i=0;
-	while (@data = $sth->fetchrow_array) 
+	while (@data = $sth->fetchrow_array)
 	{
 		@displays[$i++]='|'.@data[0].'|';
 	}
@@ -471,7 +500,7 @@ sub db_getports
 	$sth->execute()or die;
 	my @data;
 	my $i=0;
-	while (@data = $sth->fetchrow_array) 
+	while (@data = $sth->fetchrow_array)
 	{
 		@ports[$i++]='|'.@data[0].'|';
 	}
@@ -489,7 +518,7 @@ sub db_getservers
 	$sth->execute()or die;
 	my @data;
 	my $i=0;
-	while (@data = $sth->fetchrow_array) 
+	while (@data = $sth->fetchrow_array)
 	{
 		@servers[$i++]=@data[0]." ".@data[1];
 	}
@@ -510,7 +539,7 @@ sub db_getagent
 	$sth->execute()or die;
 	my @data;
 	my $i=0;
-	if (@data = $sth->fetchrow_array) 
+	if (@data = $sth->fetchrow_array)
 	{
 		$agent=@data[0];
 	}
@@ -531,7 +560,7 @@ sub db_getdisplay
 	$sth->execute() or die;
 	my @data;
 	my $i=0;
-	if (@data = $sth->fetchrow_array) 
+	if (@data = $sth->fetchrow_array)
 	{
 		$display=@data[0];
 	}
@@ -565,7 +594,7 @@ sub db_listsessions
 	$sth->execute() or die;
 	my @data;
 	my $i=0;
-	while (@data = $sth->fetchrow_array) 
+	while (@data = $sth->fetchrow_array)
 	{
 		@sessions[$i++]=join('|',@data);
 	}
@@ -598,7 +627,7 @@ sub db_listsessions_all
 	$sth->execute()or die;
 	my @data;
 	my $i=0;
-	while (@data = $sth->fetchrow_array) 
+	while (@data = $sth->fetchrow_array)
 	{
 		@sessions[$i++]=join('|',@data);
 	}
@@ -622,7 +651,7 @@ sub db_listshadowsessions
 	$sth->execute() or die;
 	my @data;
 	my $i=0;
-	while (@data = $sth->fetchrow_array) 
+	while (@data = $sth->fetchrow_array)
 	{
 		@sessions[$i++]=join('|',@data);
 	}
@@ -645,7 +674,7 @@ sub db_listshadowsessions_all
 	$sth->execute()or die;
 	my @data;
 	my $i=0;
-	while (@data = $sth->fetchrow_array) 
+	while (@data = $sth->fetchrow_array)
 	{
 		@sessions[$i++]=join('|',@data);
 	}
