@@ -1,10 +1,10 @@
 #!/usr/bin/perl
 
-# Copyright (C) 2007-2015 X2Go Project - http://wiki.x2go.org
-# Copyright (C) 2007-2015 Oleksandr Shneyder <oleksandr.shneyder@obviously-nice.de>
-# Copyright (C) 2007-2015 Heinz-Markus Graesing <heinz-m.graesing@obviously-nice.de>
+# Copyright (C) 2007-2023 X2Go Project - https://wiki.x2go.org
+# Copyright (C) 2007-2023 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>
+# Copyright (C) 2007-2023 Heinz-Markus Graesing <heinz-m.graesing@obviously-nice.de>
 # Copyright (C) 2013-2015 Guangzhou Nianguan Electronics Technology Co.Ltd. <opensource@gznianguan.com>
-# Copyright (C) 2013-2015 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2013-2023 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@ use strict;
 
 use base 'Exporter';
 
-our @EXPORT = ( 'load_module', 'is_true',
+our @EXPORT = ( 'load_module', 'is_true', 'is_int',
                 'source_environment', 'clups', 'sanitizer',
                 'system_capture_merged_output', 'system_capture_stdout_output',
                 'check_x2go_sessionid');
@@ -56,11 +56,28 @@ sub load_module {
 sub is_true {
 	my $value = shift;
 	if ( $value =~ m/(1|yes|Yes|YES|on|On|ON|True|true|TRUE)/ ) {
-		return 1
+		return 1;
 	}
-	return 0
+	return 0;
 }
 
+sub is_int {
+	my $value = shift;
+	my $allow_negative = shift;
+
+	if (!(defined ($allow_negative))) {
+		$allow_negative = 0;
+	}
+
+	if ($allow_negative) {
+		return 1 if $value =~ m/-?\d+/;
+	}
+	else {
+		return 1 if $value =~ m/\d+/;
+	}
+
+	return 0;
+}
 
 sub source_environment {
 	my $name = shift;
@@ -118,7 +135,7 @@ sub sanitizer {
 		if ($string =~ /^([a-zA-Z0-9\_\-]*)$/) {
 			$string = $1;
 			return $string;
-		} else {return 0;} 
+		} else {return 0;}
 	} elsif ($type eq "pnixusername") {
 		$string =~ s/[^a-zA-Z0-9\.\_\-\@]//g;
 		if ($string =~ /^([a-zA-Z0-9\.\_][a-zA-Z0-9\.\_\-\@]*)$/) {
@@ -129,7 +146,7 @@ sub sanitizer {
 		$string =~ s/[^a-zA-Z0-9\.\_\-\@]//g;
 		if ($string =~ /^([a-zA-Z0-9\.\_\-\@]*)$/) {
 			$string = $1;
-			if ($string =~ /^([a-zA-Z0-9\.\_][a-zA-Z0-9\.\_\-\@]*)\-([\d]{2,4})\-([\d]{9,12})\_[a-zA-Z0-9\.\_\-]*\_dp[\d]{1,2}$/) {
+			if ($string =~ /^([a-zA-Z0-9\.\_][a-zA-Z0-9\.\_\-\@]*)\-([\d]{2,4})\-([\d]{9,12})\_[a-zA-Z0-9\.\_\-]*\_dp[\d]{1,2}[a-zA-Z0-9\.\_\-]*$/) {
 				return $string;
 			} else {return 0;}
 		} else {return 0;}
