@@ -1,8 +1,8 @@
-# Copyright (C) 2007-2018 X2Go Project - https://wiki.x2go.org
-# Copyright (C) 2007-2018 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>
-# Copyright (C) 2007-2018 Heinz-Markus Graesing <heinz-m.graesing@obviously-nice.de>
+# Copyright (C) 2007-2023 X2Go Project - https://wiki.x2go.org
+# Copyright (C) 2007-2023 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>
+# Copyright (C) 2007-2023 Heinz-Markus Graesing <heinz-m.graesing@obviously-nice.de>
 # Copyright (C) 2017-2018 Walid Moghrabi <w.moghrabi@servicemagic.eu>
-# Copyright (C) 2018      Mihai Moldovan <ionic@ionic.de>
+# Copyright (C) 2018-2023 Mihai Moldovan <ionic@ionic.de>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -129,7 +129,7 @@ sub validate_session_id
 	$uname_ =~ s/\\//;
 
 	# perform the user check
-	$user =~ s/($uname_-[0-9]{2,}-[0-9]{10,}_st(D|R).*|.*-[0-9]{2,}-[0-9]{10,}_stS(0|1)XSHAD$uname_.*)/$uname_/;
+	$user =~ s/($uname_-[0-9]{2,}-[0-9]{10,}_st(D|R|K).*|.*-[0-9]{2,}-[0-9]{10,}_stS(0|1)XSHAD$uname_.*)/$uname_/;
 	die "$uname_ is not authorized to perform this operation" unless ($uname_ eq $user);
 }
 
